@@ -25,3 +25,5 @@ ALL = '--all'
 DAEMONIZE = '--daemonize'
 LIBRARIES = '--libraries'
 OPTIMIZE_FOR_DEBUG = '--optimize-for-debug'
+DRY_RUN = '--dry-run'
+INTERPRETER = '--interpreter'
